#ifndef TrivialCommandLine_csc
#define TrivialCommandLine_csc

#include "globals.hh"
#include "G4UImessenger.hh"

class GeoDet;
class G4UIdirectory;
class G4UIcmdWithAString;
class G4UIcmdWithAnInteger;
class G4UIcmdWithADoubleAndUnit;
class G4UIcmdWithoutParameter;
class G4UIcmdWith3VectorAndUnit;
class G4Material;


/** 
 *  Command line interface for changing simulation parameters.
 *  This class implements several GEANT4 command line commands which
 *  can be used interactively or in a G4-macro to change simulation
 *  parameters. It uses TrivialSettings as a central repository for
 *  keeping the changed parameters.
 *  Check the G4 User's Guide for more details on
 *  messenger classes:
 * <a href="../../../../man/g4ug/UsersGuides/ForApplicationDeveloper/html/Control/userInterfaceCommand.html" target="_blank">
 * G4 user's guide</a>
 */
class TrivialCommandLine : public G4UImessenger
{
  
public:

  TrivialCommandLine(); /**< Creates several G4 commands */
  
  ~TrivialCommandLine(); /**< Deletes the created commands  */

  /** Overloaded: Try to apply a new value if the command is managed by this class. */
  void SetNewValue(G4UIcommand* command, G4String newValue);

private:

  G4UIdirectory* cmdDir_; /**< Command-directory within which our new commands will be defined. */

  // ----------------------------------------------------------------------
  // Commands for the detector description
  // ----------------------------------------------------------------------
  /** 
   * Changes the material of a target. 
   * The class handling this command is a G4 utility that knows
   * how to treat a command line command with one string as
   * additonal argument.
   *
   * For more details, refer to the 
   * <a href="../../../../man/g4ug/UsersGuides/ForApplicationDeveloper/html/Control/userInterfaceCommand.html" target="_blank">
   * G4 user's guide</a>
   */
  G4UIcmdWithAString* targetMaterialCmd_; 

  /**
   * G4 command line handler for specifying the size of the target cube.
   *
   * For more details about command line handlers, refer to the 
   * <a href="../../../../man/g4ug/UsersGuides/ForApplicationDeveloper/html/Control/userInterfaceCommand.html" target="_blank">
   * G4 user's guide</a>
   *
   */
  G4UIcmdWithADoubleAndUnit* targetSizeCmd_;
};

#endif
