#include "EnergyCollector.hh"

#include "G4Step.hh"
#include "G4TouchableHistory.hh"

#include "globals.hh"


/**
 * Opens a file to store simulation output.
 */
EnergyCollector::EnergyCollector()
  : G4VSensitiveDetector("TrivialEnergyCollector"),
    file_("etotal.txt")
{
  totalEnergy_ = 0.;
  G4cout << "-- EnergyCollector: constructed. " << G4endl;
}


/**
 * Closes the file into which simulation output is stored.
 */
EnergyCollector::~EnergyCollector()
{
  
  // Close the file
  file_.close();

  G4cout << "-- EnergyCollector: destructed." << G4endl;
}


/**
 * Normally, at the beginning of each simulation event 
 * lots of "administrative" work concerning hits
 * has to be done.
 *
 * Here we only need to remember to reset the
 * variable that stores the accumulated energy
 * of one event in order not to add the energies
 * of subsequent events to it ...
 */
void EnergyCollector::Initialize(G4HCofThisEvent*)
{
  //////////////////////////////////////////////////////////////
  // Your code ... please ;-)

 
}


/**
 * At each step, we have to ask the step how much energy
 * it has deposited within the sensitive volume.
 * We sum this energy up so that at the end of the event
 * the total deposited energy can be stored.
 */
G4bool EnergyCollector::ProcessHits(G4Step* aStep,
				    G4TouchableHistory*)
{
  ////////////////////////////////////////////////////////////
  // An again, you have to work here ...

 
  // We always return true .... 
  // (I did not find a G4 document describing the purpose of this boolean..)
  return true;
}


/**
 * At the end of the event, the total energy deposited
 * during the event processing has to be saved into
 * a ROOT file.
 */
void EnergyCollector::EndOfEvent(G4HCofThisEvent*)
{
  G4cout << "-- EnergyCollector: end of event." << G4endl;
  file_ << totalEnergy_ / GeV << G4endl;
}


